import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.logging.Level;
import java.util.logging.Logger;

public class EchoServer {

    private static final Logger LOG = Logger.getLogger(EchoServer.class.getName());

    private ServerSocket serverSocket;
    private Socket clientSocket;
    private PrintWriter out;
    private BufferedReader in;

    public void start(int port) {
        try {
            serverSocket = new ServerSocket(port);
            clientSocket = serverSocket.accept();
            out = new PrintWriter(clientSocket.getOutputStream(), true);
            in = new BufferedReader(new InputStreamReader(clientSocket.getInputStream()));
            String inputLine;
            while ((inputLine = in.readLine()) != null) {
                if ("end".equals(inputLine)) {
                    out.println("server shut down");
                    break;
                }
                out.println(inputLine);
            }
        } catch (IOException e) {
            LOG.log(Level.SEVERE, "Exception occur", e);
        }
    }

    public void stop() {
        try {
            in.close();
            out.close();
            clientSocket.close();
            serverSocket.close();
        } catch (IOException e) {
            LOG.log(Level.SEVERE, "Exception occur", e);
        }

    }

    public static void main(String[] args) {
        EchoServer server = new EchoServer();
        server.start(4444);
    }

}
